.. _signal_analysis.hurst:

Hurst Exponent
==============

.. automodule:: eyetrace.signal_analysis.hurst
   :members:
   :undoc-members:
   :show-inheritance:

The Hurst exponent measures the long‑term memory of a time series. Values
greater than 0.5 indicate persistence (trend‑reinforcing), less than 0.5
indicates anti‑persistence (mean‑reverting), and 0.5 corresponds to a random
walk.